@@ -36,7 +36,7 @@
 import warnings
 
 from collections import deque
-from collections.abc import Sequence
+from collections.abc import Collection, Sequence
 
 import pytensor.tensor as pt
 
@@ -72,7 +72,6 @@ from pytensor.tensor.random.rewriting import local_subtensor_rv_lift
 from pytensor.tensor.rewriting.basic import register_canonicalize
 from pytensor.tensor.rewriting.math import local_exp_over_1_plus_exp
 from pytensor.tensor.rewriting.shape import ShapeFeature
-from pytensor.tensor.rewriting.uncanonicalize import local_max_and_argmax
 from pytensor.tensor.subtensor import (
     AdvancedIncSubtensor,
     AdvancedIncSubtensor1,
@@ -374,12 +373,6 @@ measurable_ir_rewrites_db.name = "measurable_ir_rewrites_db"
 
 logprob_rewrites_db.register("measurable_ir_rewrites", measurable_ir_rewrites_db, "basic")
 
-# Split max_and_argmax
-# We only register this in the measurable IR db because max does not have a grad implemented
-# And running this on any MaxAndArgmax would lead to issues: https://github.com/pymc-devs/pymc/issues/7251
-# This special registering can be removed after https://github.com/pymc-devs/pytensor/issues/334 is fixed
-measurable_ir_rewrites_db.register("local_max_and_argmax", local_max_and_argmax, "basic")
-
 # These rewrites push random/measurable variables "down", making them closer to
 # (or eventually) the graph outputs.  Often this is done by lifting other `Op`s
 # "up" through the random/measurable variables and into their inputs.
@@ -484,7 +477,7 @@ def cleanup_ir(vars: Sequence[Variable]) -> None:
 
 
 def assume_measured_ir_outputs(
-    inputs: Sequence[TensorVariable], outputs: Sequence[TensorVariable]
+    inputs: Collection[TensorVariable], outputs: Sequence[TensorVariable]
 ) -> Sequence[TensorVariable]:
     """Run IR rewrite assuming each output is measured.
 
