@@ -32,10 +32,11 @@ from pytensor.graph.basic import (
     Constant,
     Variable,
     clone_get_equiv,
+    equal_computations,
     graph_inputs,
     walk,
 )
-from pytensor.graph.fg import FunctionGraph
+from pytensor.graph.fg import FunctionGraph, Output
 from pytensor.graph.op import Op
 from pytensor.scalar.basic import Cast
 from pytensor.scan.op import Scan
@@ -872,8 +873,23 @@ def collect_default_updates(
             return rng
 
         if len(rng_clients) > 1:
+            # Multiple clients are techincally fine if they are used in identical operations
+            # We check if the default_update of each client would be the same
+            update, *other_updates = (
+                find_default_update(
+                    # Pass version of clients that includes only one the RNG clients at a time
+                    clients | {rng: [rng_client]},
+                    rng,
+                )
+                for rng_client in rng_clients
+            )
+            if all(equal_computations([update], [other_update]) for other_update in other_updates):
+                return update
+
             warnings.warn(
-                f"RNG Variable {rng} has multiple clients. This is likely an inconsistent random graph.",
+                f"RNG Variable {rng} has multiple distinct clients {rng_clients}, "
+                f"likely due to an inconsistent random graph. "
+                f"No default update will be returned.",
                 UserWarning,
             )
             return None
@@ -881,7 +897,7 @@ def collect_default_updates(
         [client, _] = rng_clients[0]
 
         # RNG is an output of the function, this is not a problem
-        if client == "output":
+        if isinstance(client.op, Output):
             return rng
 
         # RNG is used by another operator, which should output an update for the RNG
