@@ -1,4 +1,4 @@
-#   Copyright 2023 The PyMC Developers
+#   Copyright 2024 The PyMC Developers
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -108,6 +108,7 @@ Notes
 Taken from the Lasagne project: http://lasagne.readthedocs.io/en/latest/
 
 """
+
 from collections import OrderedDict
 from functools import partial
 
@@ -570,7 +571,7 @@ def adagrad_window(loss_or_grads=None, params=None, learning_rate=0.001, epsilon
         i = pytensor.shared(pm.floatX(0))
         i_int = i.astype("int32")
         value = param.get_value(borrow=True)
-        accu = pytensor.shared(np.zeros(value.shape + (n_win,), dtype=value.dtype))
+        accu = pytensor.shared(np.zeros((*value.shape, n_win), dtype=value.dtype))
 
         # Append squared gradient vector to accu_new
         accu_new = pt.set_subtensor(accu[..., i_int], grad**2)
@@ -1005,9 +1006,7 @@ def norm_constraint(tensor_var, max_norm, norm_axes=None, epsilon=1e-7):
     elif ndim in [3, 4, 5]:  # Conv{1,2,3}DLayer
         sum_over = tuple(range(1, ndim))
     else:
-        raise ValueError(
-            "Unsupported tensor dimensionality {}." "Must specify `norm_axes`".format(ndim)
-        )
+        raise ValueError(f"Unsupported tensor dimensionality {ndim}." "Must specify `norm_axes`")
 
     dtype = np.dtype(pytensor.config.floatX).type
     norms = pt.sqrt(pt.sum(pt.sqr(tensor_var), axis=sum_over, keepdims=True))
