@@ -130,6 +130,34 @@ class TestBaseModel:
         assert m["d"] is model["one_more::d"]
         assert m["one_more::d"] is model["one_more::d"]
 
+    def test_docstring_example(self):
+        with pm.Model(name="root") as root:
+            x = pm.Normal("x")  # Variable wil be named "root::x"
+
+            with pm.Model(name="first") as first:
+                # Variable will belong to root and first
+                y = pm.Normal("y", mu=x)  # Variable wil be named "root::first::y"
+
+            # Can pass parent model explicitly
+            with pm.Model(name="second", model=root) as second:
+                # Variable will belong to root and second
+                z = pm.Normal("z", mu=y)  # Variable wil be named "root::second::z"
+
+            # Set None for standalone model
+            with pm.Model(name="third", model=None) as third:
+                # Variable will belong to third only
+                w = pm.Normal("w")  # Variable wil be named "third::w"
+
+        assert x.name == "root::x"
+        assert y.name == "root::first::y"
+        assert z.name == "root::second::z"
+        assert w.name == "third::w"
+
+        assert set(root.basic_RVs) == {x, y, z}
+        assert set(first.basic_RVs) == {y}
+        assert set(second.basic_RVs) == {z}
+        assert set(third.basic_RVs) == {w}
+
 
 class TestNested:
     def test_nest_context_works(self):
@@ -862,7 +890,17 @@ class TestSetUpdateCoords:
             rv2.name = "yumyum"
             pmodel.add_named_variable(rv2, dims=("nomnom", None))
 
-    def test_dims_type_check(self):
+    def test_add_named_variable_checks_number_of_dims(self):
+        match = "dim labels were provided"
+        with pm.Model(coords={"bad": range(6)}) as m:
+            with pytest.raises(ValueError, match=match):
+                m.add_named_variable(pt.random.normal(size=(6, 6, 6), name="a"), dims=("bad",))
+
+            # "bad" is an iterable with 3 elements, but we treat strings as a single dim, so it's still invalid
+            with pytest.raises(ValueError, match=match):
+                m.add_named_variable(pt.random.normal(size=(6, 6, 6), name="b"), dims="bad")
+
+    def test_rv_dims_type_check(self):
         with pm.Model(coords={"a": range(5)}) as m:
             with pytest.raises(TypeError, match="Dims must be string"):
                 x = pm.Normal("x", shape=(10, 5), dims=(None, "a"))
@@ -871,12 +909,14 @@ class TestSetUpdateCoords:
         # TODO: Either allow dims without coords everywhere or nowhere
         with pm.Model() as m:
             m.add_coord(name="a", values=None, length=3)
-            m.add_coord(name="b", values=range(5))
-            x = pm.Normal("x", dims=("a", "b"))
-            prior = pm.sample_prior_predictive(samples=2).prior
-        assert prior["x"].shape == (1, 2, 3, 5)
+            m.add_coord(name="b", values=range(-5, 0))
+            m.add_coord(name="c", values=None, length=7)
+            x = pm.Normal("x", dims=("a", "b", "c"))
+            prior = pm.sample_prior_predictive(draws=2).prior
+        assert prior["x"].shape == (1, 2, 3, 5, 7)
         assert list(prior.coords["a"].values) == list(range(3))
-        assert list(prior.coords["b"].values) == list(range(5))
+        assert list(prior.coords["b"].values) == list(range(-5, 0))
+        assert list(prior.coords["c"].values) == list(range(7))
 
     def test_set_data_indirect_resize_without_coords(self):
         with pm.Model() as pmodel:
@@ -900,7 +940,7 @@ class TestSetUpdateCoords:
 
     def test_set_data_indirect_resize_with_coords(self):
         with pm.Model() as pmodel:
-            pmodel.add_coord("mdim", ["A", "B"], mutable=True, length=2)
+            pmodel.add_coord("mdim", ["A", "B"], length=2)
             pm.Data("mdata", [1, 2], dims="mdim")
 
         assert pmodel.coords["mdim"] == ("A", "B")
@@ -1040,7 +1080,7 @@ def test_determinsitic_with_dims():
     Test to check the passing of dims to the potential
     """
     with pm.Model(coords={"observed": range(10)}) as model:
-        x = pm.Normal("x", 0, 1)
+        x = pm.Normal("x", 0, 1, shape=(10,))
         y = pm.Deterministic("y", x**2, dims=("observed",))
     assert model.named_vars_to_dims == {"y": ("observed",)}
 
@@ -1050,7 +1090,7 @@ def test_potential_with_dims():
     Test to check the passing of dims to the potential
     """
     with pm.Model(coords={"observed": range(10)}) as model:
-        x = pm.Normal("x", 0, 1)
+        x = pm.Normal("x", 0, 1, shape=(10,))
         y = pm.Potential("y", x**2, dims=("observed",))
     assert model.named_vars_to_dims == {"y": ("observed",)}
 
@@ -1077,22 +1117,6 @@ def test_compile_fn():
     np.testing.assert_allclose(result_compute, result_expect)
 
 
-def test_model_pytensor_config():
-    assert pytensor.config.mode != "JAX"
-    with pytest.warns(FutureWarning, match="pytensor_config is deprecated"):
-        m = pm.Model(pytensor_config=dict(mode="JAX"))
-    with m:
-        assert pytensor.config.mode == "JAX"
-    assert pytensor.config.mode != "JAX"
-
-
-def test_deprecated_model_property():
-    m = pm.Model()
-    with pytest.warns(FutureWarning, match="Model.model property is deprecated"):
-        m_property = m.model
-    assert m is m_property
-
-
 def test_model_parent_set_programmatically():
     with pm.Model() as model:
         x = pm.Normal("x")
@@ -1100,7 +1124,18 @@ def test_model_parent_set_programmatically():
     with pm.Model(model=model):
         y = pm.Normal("y")
 
+    with model:
+        # Default inherits from model
+        with pm.Model():
+            z_in = pm.Normal("z_in")
+
+        # Explict None opts out of model context
+        with pm.Model(model=None):
+            z_out = pm.Normal("z_out")
+
     assert "y" in model.named_vars
+    assert "z_in" in model.named_vars
+    assert "z_out" not in model.named_vars
 
 
 class TestModelContext:
@@ -1621,7 +1656,7 @@ class TestModelDebug:
             # var dlogp is 0 or 1 without a likelihood
             assert "No problems found" in out
         else:
-            assert "The parameters evaluate to:\n0: 0.0\n1: [ 1. -1.  1.]" in out
+            assert "The parameters evaluate to:\n0: [0.]\n1: [ 1. -1.  1.]" in out
             if fn == "logp":
                 assert "This does not respect one of the following constraints: sigma > 0" in out
             else:
@@ -1648,7 +1683,7 @@ class TestModelDebug:
     def test_invalid_value(self, capfd):
         with pm.Model() as m:
             x = pm.Normal("x", [1, -1, 1])
-            y = pm.HalfNormal("y", tau=pm.math.abs(x), initval=[-1, 1, -1], transform=None)
+            y = pm.HalfNormal("y", tau=pm.math.abs(x), initval=[-1, 1, -1], default_transform=None)
         m.debug()
 
         out, _ = capfd.readouterr()
